ants.contrib.sampling package
=============================

Submodules
----------

ants.contrib.sampling.affine2d module
-------------------------------------

.. automodule:: ants.contrib.sampling.affine2d
   :members:
   :undoc-members:
   :show-inheritance:

ants.contrib.sampling.affine3d module
-------------------------------------

.. automodule:: ants.contrib.sampling.affine3d
   :members:
   :undoc-members:
   :show-inheritance:

ants.contrib.sampling.transforms module
---------------------------------------

.. automodule:: ants.contrib.sampling.transforms
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: ants.contrib.sampling
   :members:
   :undoc-members:
   :show-inheritance:
